==> haskell-enclosed-exceptions-1.0.3-316-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-5AjXmmSE9IyFXhaAQfvAY9
key:                  enclosed-exceptions-1.0.3-5AjXmmSE9IyFXhaAQfvAY9
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  829f772d2f0e52b902bb91d543915556
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enclosed-exceptions
hs-libraries:         HSenclosed-exceptions-1.0.3-5AjXmmSE9IyFXhaAQfvAY9
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    lifted-base-0.2.3.12-46PMFFwHq433EzOiQf2fR8
    monad-control-1.0.3.1-GdYOmvlqhHogrDZjExWLd transformers-0.5.6.2
    transformers-base-0.4.6-Ca46p1Mgu1T6naM3ijNQiM

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-317-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-GKr7kQ0xGRGBz0j5mv8JXH
key:                  enclosed-exceptions-1.0.3-GKr7kQ0xGRGBz0j5mv8JXH
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  87528f540989337d150e3f2a507b9fe6
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enclosed-exceptions
hs-libraries:         HSenclosed-exceptions-1.0.3-GKr7kQ0xGRGBz0j5mv8JXH
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    lifted-base-0.2.3.12-EnVegiEIDLdHoooihSye2u
    monad-control-1.0.3.1-8hRw9mjLBLl6PAQlNWysTu transformers-0.5.6.2
    transformers-base-0.4.6-9k6sqnTM6dd156kd3yeDl4

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
